rm_matching_files

Function rm_matching_files 

pub fn rm_matching_files<P: AsRef<Path>>(
    root_path: P,
    file_name: &str,
    excluded_dirs: &[&str],
    dry_run: bool,
) -> RmFilesOutcome
Iteratively removes all files with the specified name starting from the given root path, with optional directory exclusions.